@@ -1,46 +1,8 @@
-use list_fn::{FlatMap, FlatMapFn, FlatMapList, ListFn, ListSome, ListState, ResultFn};
+use lim_bit_vec::BitVec;
+use list_fn::{FlatMap, FlatMapFn, FlatMapList, ListFn, ResultFn};
 use std::marker::PhantomData;
 use uints::UInt;
 
-// LSB first bit vector.
-#[derive(Clone, Copy, Debug, PartialEq, Default)]
-pub struct BitVec<T: UInt> {
-    pub array: T,
-    pub size: u8,
-}
-
-impl<T: UInt> BitVec<T> {
-    pub fn new_full(array: T) -> Self {
-        Self::new(array, T::BITS)
-    }
-    pub fn new(array: T, size: u8) -> Self {
-        BitVec { array, size }
-    }
-    pub fn concat(self, v: Self) -> Self {
-        BitVec {
-            array: self.array | (v.array << self.size),
-            size: self.size + v.size,
-        }
-    }
-}
-
-impl<T: UInt> ListFn for BitVec<T> {
-    type Item = bool;
-    type End = ();
-    fn next(self) -> ListState<Self> {
-        match self.size {
-            0 => ListState::End(()),
-            size => ListState::Some(ListSome {
-                first: self.array & T::ONE != T::ZERO,
-                next: BitVec {
-                    array: self.array >> 1,
-                    size: size - 1,
-                },
-            }),
-        }
-    }
-}
-
 pub struct Lsb0FlatMap<T: UInt>(PhantomData<T>);
 
 impl<T: UInt> Default for Lsb0FlatMap<T> {
